Processor.processor.Message
===========================

.. currentmodule:: Processor.processor

.. autoclass:: Message

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree:

   
      ~Message.__init__
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~Message.dr
      ~Message.headers
   
   